Stan Math Library: stan/math/prim/mat/fun/corr_matrix_free.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
corr_matrix_free.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/mat/err/constraint_tolerance.hpp>`
`#include <stan/math/prim/mat/fun/factor_cov_matrix.hpp>`
`#include <boost/throw_exception.hpp>`
`#include <cmath>`
`#include <sstream>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, 1 > | stan::math::corr_matrix_free (const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &y)
| Return the vector of unconstrained partial correlations that define the specified correlation matrix when transformed. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.